//---------------------------------------------------------------
//Analog Devices, Inc.  All rights reserved.
//
//Project Name:	AD7656_BF537 C
//
//Date Modified:	6/2007	Ver 0.0
//
//Hardware:		ADSP-BF537 EZ-KIT Lite

//----------------------------------------------------------------

#include "BF537 Flags.h"
#include "ccblkfn.h"
#include "sysreg.h"

//----------------------------------------------------------------
// Variables						
//----------------------------------------------------------------

unsigned short OpMode = BLOCK;
unsigned short Int2Cnt = 0;
unsigned short AD7656IntCnt = 0;
unsigned short RunFFT = 0;


//target buffer for DMA read of AD7656
fract16 section("SDdata1") AD7656_input[VEC_SIZE * CHAN_CNT];
                                                         
int indx, n;

fract16 section("data1") FractIn[VEC_SIZE];

complex_fract16 section("data1") w[TWIDDLE_SIZE];

// temp storage
complex_fract16 section("data2") t[VEC_SIZE];  

// output
complex_fract16 section("data2") out[VEC_SIZE];


void twidfftrad2_fr16 (complex_fract16 w[], int n);


//--------------------------------------------------------------------------
// Function:	main														
//--------------------------------------------------------------------------
void main(void)
{
    //PLL (CCLK) set to 500 MHz using autogenerated startup code
    
    *pPLL_DIV = 5;                     //sclk = 20 MHz

	Init_Flags();
    Init_EBIU();
    Init_AD7656();
	Init_Interrupts();
	Init_Timers();
  
          n = VEC_SIZE;     
          twidfftrad2_fr16 (w, n); //VDSP DSP library FFT convenience function.
                                   //see VDSP compiler manual for usage
	
while(1)
    {	
	if(RunFFT == 1)
	    {
	    
	        //Move AD7656 data from SDRAM to internal SRAM.
	        //May bypass this step and DMA straight to internal SRAM
	        //however, this placeholder allows for possible scaling;
	        //and, the end application may benefit from AD7656 data DMA 
	        //to SDRAM for a number of possible reasons - large sample array 
            //for instance ..
	        
	        //AD7656 Data is assumed to be fract16
	      
	      
	         for( indx=0; indx < (VEC_SIZE*CHAN_CNT); indx+=CHAN_CNT ) 
             {
                 FractIn[indx/CHAN_CNT] = AD7656_input[indx];
             }	        
	        
     
    //  FFT call linkage description - see VDSP compiler manual
    
        void rfft_fr16(
        const fract16  *in,       // Input array
        complex_fract16 *t,       // Temporary buffer
        complex_fract16 *out,     // Output array
        const complex_fract16 *w, // Twiddle table 
        int wst,                  // Twiddle stride
        int n,                    // Size FFT
        int block_exponent,       // Not used
        int scale_method);        // Not used */ 


	// Call FFT - view results using VDSP plot window. Open VDSP
	// workspace ../debug/phil.vdw for automated plot window configuration
	    
	    rfft_fr16(FractIn, t, out, w, 1, VEC_SIZE, 1, 2);
        RunFFT = 0;
        
     
	    } 
    }	       
}

